@@ -1,4 +1,9 @@
-use crate::request::prelude::*;
+use crate::{
+    client::Client,
+    error::Error,
+    request::{Pending, Request},
+    routing::Route,
+};
 use twilight_model::{id::GuildId, voice::VoiceRegion};
 
 /// Get voice region data for the guild.
@@ -19,7 +24,7 @@ impl<'a> GetGuildVoiceRegions<'a> {
         }
     }
 
-    fn start(&mut self) -> Result<()> {
+    fn start(&mut self) -> Result<(), Error> {
         let request = Request::from_route(Route::GetGuildVoiceRegions {
             guild_id: self.guild_id.0,
         });
