@@ -94,7 +94,7 @@ struct SearchGuildMembersFields {
 /// use twilight_model::id::GuildId;
 ///
 /// # #[tokio::main]
-/// # async fn main() -> Result<(), Box<dyn std::error::Error + Send + Sync>> {
+/// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
 /// let client = Client::new("my token");
 ///
 /// let guild_id = GuildId(100);
@@ -179,9 +179,8 @@ impl Future for SearchGuildMembers<'_> {
                 let bytes = res?;
                 let mut members = Vec::new();
 
-                let mut bytes = bytes.as_ref().to_vec();
                 let values =
-                    crate::json::from_slice::<Vec<Value>>(&mut bytes).map_err(HttpError::json)?;
+                    crate::json::from_bytes::<Vec<Value>>(&bytes).map_err(HttpError::json)?;
 
                 for value in values {
                     let member_deserializer = MemberDeserializer::new(self.guild_id);
